@@ -1,17 +1,19 @@
 import platform
 import sys
+from pathlib import Path
 
 import click
 import openai
 
 from vocabmaster import config_handler, csv_handler, gpt_integration
 
-from .utils import *
+from .utils import openai_api_key_exists, setup_backup_dir, setup_dir, setup_files
 
 
-@click.group()
+@click.group(invoke_without_command=True)
 @click.version_option()
-def vocabmaster():
+@click.pass_context
+def vocabmaster(ctx):
     """
     VocabMaster is a command-line tool to help you learn vocabulary.
 
@@ -32,7 +34,8 @@ def vocabmaster():
 
     For more information, please visit https://github.com/sderev/vocabmaster.
     """
-    pass
+    if ctx.invoked_subcommand is None:
+        click.echo(ctx.get_help())
 
 
 @vocabmaster.command()
@@ -57,7 +60,8 @@ def add(pair, word):
     try:
         language_to_learn, mother_tongue = config_handler.get_language_pair(pair)
     except Exception as error:
-        click.echo(f"{RED}Error:{RESET} {error}")
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(error, err=True)
         sys.exit(1)
 
     translations_filepath, anki_filepath = setup_files(
@@ -67,7 +71,9 @@ def add(pair, word):
     if not word:
         click.echo()
         click.echo("Please provide a word to add.")
-        click.echo(f"Run '{BOLD}vocabmaster add --help{RESET}' for more information.")
+        click.echo(
+            f"Run '{click.style('vocabmaster add --help', bold=True)}' for more information."
+        )
         sys.exit(0)
 
     word = " ".join(word)
@@ -106,7 +112,8 @@ def translate(pair, count):
     try:
         language_to_learn, mother_tongue = config_handler.get_language_pair(pair)
     except Exception as error:
-        click.echo(f"{RED}Error:{RESET} {error}")
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(error, err=True)
         sys.exit(1)
 
     translations_filepath, anki_filepath = setup_files(
@@ -114,14 +121,16 @@ def translate(pair, count):
     )
 
     # Add the fieldnames to the CSV file if it's missing
-    csv_handler.add_fieldnames_to_csv_file(
-        translations_filepath, ["word", "translation", "example"]
-    )
+    csv_handler.ensure_csv_has_fieldnames(translations_filepath)
 
     # Check if the vocabulary list is empty
     if csv_handler.vocabulary_list_is_empty(translations_filepath):
-        click.echo(f"{RED}Your vocabulary list is empty.{RESET} Please add some words first.")
-        click.echo(f"Run '{BOLD}vocabmaster add --help{RESET}' for more information.")
+        click.secho("Your vocabulary list is empty.", fg="red", nl=False, err=True)
+        click.echo(" Please add some words first.", err=True)
+        click.echo(
+            f"Run '{click.style('vocabmaster add --help', bold=True)}' for more information.",
+            err=True,
+        )
         sys.exit(0)
 
     # Show untranslated words count if `--count` is used, then exit.
@@ -129,9 +138,10 @@ def translate(pair, count):
         try:
             number_words = len(csv_handler.get_words_to_translate(translations_filepath))
         except Exception as error:
-            click.echo(f"{GREEN}Status:{RESET} {error}")
+            click.secho("Status: ", fg="green", nl=False)
+            click.echo(error)
         else:
-            click.echo(f"Number of words to translate: {BLUE}{number_words}{RESET}")
+            click.echo(f"Number of words to translate: {click.style(str(number_words), fg='blue')}")
         sys.exit(0)
 
     # Check for OpenAI API key
@@ -141,14 +151,14 @@ def translate(pair, count):
 
     # Add translations and examples to the CSV file
     click.echo("Adding translations and examples to the file... 🔎📝")
-    click.echo(f"{BLUE}This may take a while...{RESET}")
+    click.secho("This may take a while...", fg="blue")
     click.echo()
 
     try:
         csv_handler.add_translations_and_examples_to_file(translations_filepath, pair)
         click.echo()
     except openai.error.RateLimitError as error:
-        click.echo(click.style("Error: ", fg="red") + f"{error}")
+        click.echo(click.style("Error: ", fg="red") + f"{error}", err=True)
         handle_rate_limit_error()
         sys.exit(1)
     except Exception as error:
@@ -156,17 +166,18 @@ def translate(pair, count):
             str(error) == "All the words in the vocabulary list already have translations and"
             " examples"
         ):
-            click.echo(f"{BLUE}Actually...{RESET}")
-            click.echo(f"{GREEN}No action needed:{RESET} {error} 🤓")
+            click.secho("Actually...", fg="blue")
+            click.secho("No action needed: ", fg="green", nl=False)
+            click.echo(f"{error} 🤓")
             click.echo(
-                "If you only want to generate the Anki deck, you can run"
-                f" '{BOLD}vocabmaster anki{RESET}'."
+                f"If you only want to generate the Anki deck, you can run '{click.style('vocabmaster anki', bold=True)}'."
             )
         else:
-            click.echo(f"{RED}Status:{RESET} {error}")
+            click.secho("Status: ", fg="red", nl=False, err=True)
+            click.echo(error, err=True)
         sys.exit(0)
-    click.echo(
-        f"{BLUE}The translations and examples have been added to the vocabulary list{RESET} 💡✅"
+    click.secho(
+        "The translations and examples have been added to the vocabulary list 💡✅", fg="blue"
     )
 
     # Generate the Anki deck
@@ -193,12 +204,14 @@ def generate_anki_deck(translations_filepath, anki_filepath, language_to_learn,
     click.echo()
     click.echo("Generating the Anki deck... 📜")
     click.echo()
-    csv_handler.generate_anki_output_file(translations_filepath, anki_filepath, language_to_learn, mother_tongue)
+    csv_handler.generate_anki_output_file(
+        translations_filepath, anki_filepath, language_to_learn, mother_tongue
+    )
     click.echo("The Anki deck has been generated 🤓✅")
     click.echo()
-    click.echo(f"{GREEN}You can now import the deck into Anki{RESET} 📚")
+    click.secho("You can now import the deck into Anki 📚", fg="green")
 
-    click.echo(f"{BOLD}The deck is located at:{RESET}")
+    click.secho("The deck is located at:", bold=True)
     click.echo(f"{anki_filepath}")
 
 
@@ -209,8 +222,17 @@ def anki():
 
     The Anki deck will be saved in the same folder as your vocabulary list.
     """
-    language_to_learn = config_handler.get_default_language_pair()["language_to_learn"]
-    mother_tongue = config_handler.get_default_language_pair()["mother_tongue"]
+    default_pair = config_handler.get_default_language_pair()
+    if default_pair is None:
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(
+            "No default language pair found. Run 'vocabmaster setup' to create one.",
+            err=True,
+        )
+        sys.exit(1)
+
+    language_to_learn = default_pair["language_to_learn"]
+    mother_tongue = default_pair["mother_tongue"]
 
     translations_filepath, anki_filepath = setup_files(
         setup_dir(), language_to_learn, mother_tongue
@@ -236,9 +258,8 @@ def setup():
 
     click.echo()
     click.echo(
-        "Setting up VocabMaster for learning"
-        f" {BOLD}{language_to_learn.capitalize()}{RESET}, and"
-        f" {BOLD}{mother_tongue.capitalize()}{RESET} is your mother tongue."
+        f"Setting up VocabMaster for learning {click.style(language_to_learn.capitalize(), bold=True)}, "
+        f"and {click.style(mother_tongue.capitalize(), bold=True)} is your mother tongue."
     )
 
     if click.confirm("Do you want to proceed?"):
@@ -251,7 +272,7 @@ def setup():
             app_data_dir, language_to_learn, mother_tongue
         )
 
-        backup_lang = setup_backup_dir(app_data_dir, language_to_learn, mother_tongue)
+        backup_lang = setup_backup_dir(language_to_learn, mother_tongue)
         config_handler.set_language_pair(language_to_learn, mother_tongue)
 
         click.echo()
@@ -262,7 +283,7 @@ def setup():
         click.echo(f"VocabMaster setup for {language_to_learn} to {mother_tongue} complete 🤓✅")
         click.echo()
     else:
-        click.echo(f"{RED}Setup canceled{RESET}")
+        click.secho("Setup canceled", fg="red")
 
     # Set the default language pair
     if config_handler.get_default_language_pair() is None:
@@ -276,33 +297,35 @@ def setup():
     else:
         print_default_language_pair()
 
-        if click.confirm("Do you want to set this language pair as the default?"):
-            if click.confirm(
-                f"{RED}Are you sure?{RESET} This will overwrite the current default 🚨"
-            ):
-                config_handler.set_default_language_pair(language_to_learn, mother_tongue)
+        prompt = f"Set this language pair ({language_to_learn}:{mother_tongue}) as the default?"
+        if click.confirm(prompt, default=False):
+            config_handler.set_default_language_pair(language_to_learn, mother_tongue)
             click.echo()
             click.echo("This language pair has been set as the default ✅")
-            click.echo(f"{BLUE}The new default language pair is:{RESET}")
+            click.secho("The new default language pair is:", fg="blue")
 
             # Get the new default language pair by reinitalizing the variables to avoid confusion
             default_language_to_learn = config_handler.get_default_language_pair()[
                 "language_to_learn"
             ]
             default_mother_tongue = config_handler.get_default_language_pair()["mother_tongue"]
-            click.echo(f"{BOLD}Language to learn:{RESET} {default_language_to_learn.capitalize()}")
-            click.echo(f"{BOLD}Mother tongue:{RESET} {default_mother_tongue.capitalize()}")
+            click.echo(
+                f"{click.style('Language to learn:', bold=True)} {default_language_to_learn.capitalize()}"
+            )
+            click.echo(
+                f"{click.style('Mother tongue:', bold=True)} {default_mother_tongue.capitalize()}"
+            )
             click.echo()
 
         else:
-            click.echo("This language pair has not been set as the default ❌")
+            click.echo("Keeping the existing default language pair.")
             click.echo()
             click.echo("The current default language pair is:")
             default_language_to_learn = config_handler.get_default_language_pair()[
                 "language_to_learn"
             ]
             default_mother_tongue = config_handler.get_default_language_pair()["mother_tongue"]
-            click.echo(f"{BOLD}{default_language_to_learn}:{default_mother_tongue}{RESET}")
+            click.secho(f"{default_language_to_learn}:{default_mother_tongue}", bold=True)
 
 
 @vocabmaster.command()
@@ -311,29 +334,21 @@ def default():
     Show the current default language pair.
     """
     print_default_language_pair()
-    click.echo()
-    click.echo(f"{BLUE}You can change the default language pair at any time by running:{RESET}")
-    click.echo(f"{BOLD}vocabmaster config default{RESET}")
+    click.secho("You can change the default language pair at any time by running:", fg="blue")
+    click.secho("vocabmaster config default", bold=True)
 
 
-@vocabmaster.group()
-def config():
+@vocabmaster.group(invoke_without_command=True)
+@click.pass_context
+def config(ctx):
     """
-    Manage the configuration of VocabMaster.
+    Manage VocabMaster configuration such as language pairs, storage location, and API keys.
 
-    This command allows you to set the default language pair,
-    and the OpenAI API key.
-
-    Example usage:
-    'vocabmaster config default'
-
-    Example usage:
-    'vocabmaster config key'
+    Run 'vocabmaster config dir' to choose where CSV and Anki files are stored. The configuration
+    file itself always lives under ~/.config/vocabmaster/config.json.
     """
-    # the directory where the translations and Anki decks are stored,
-    # Example usage:
-    #'vocabmaster config dir'
-    pass
+    if ctx.invoked_subcommand is None:
+        click.echo(ctx.get_help())
 
 
 @config.command("default")
@@ -347,7 +362,15 @@ def config_default_language_pair():
     """
     print_default_language_pair()
 
-    print_all_language_pairs()
+    language_pairs = print_all_language_pairs()
+    if not language_pairs:
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(
+            "No language pairs found. Run 'vocabmaster setup' to add one before setting a default.",
+            err=True,
+        )
+        sys.exit(1)
+
     choice = click.prompt(
         "Type the language pair or its number to set it as the new default",
         type=str,
@@ -356,22 +379,23 @@ def config_default_language_pair():
     # Check if the user entered a correct number
     if choice.isdigit():
         idx = int(choice) - 1
-        if 0 <= idx < len(config_handler.get_all_language_pairs()):
+        if 0 <= idx < len(language_pairs):
             # Set the language pair as the default
-            language_to_learn = config_handler.get_all_language_pairs()[idx]["language_to_learn"]
-            mother_tongue = config_handler.get_all_language_pairs()[idx]["mother_tongue"]
+            language_to_learn = language_pairs[idx]["language_to_learn"]
+            mother_tongue = language_pairs[idx]["mother_tongue"]
             config_handler.set_default_language_pair(language_to_learn, mother_tongue)
             click.echo(
-                f"{BOLD}{language_to_learn}:{mother_tongue}{RESET} {GREEN} has been set"
-                f" as the default language pair{RESET} ✅"
+                f"{click.style(f'{language_to_learn}:{mother_tongue}', bold=True)} "
+                f"{click.style('has been set as the default language pair', fg='green')} ✅"
             )
         else:
             # The user entered a number that is out of range
-            click.echo(f"{RED}Invalid choice{RESET}")
+            click.secho("Invalid choice", fg="red", err=True)
             click.echo(
-                "Please enter a number between 1 and"
-                f" {len(config_handler.get_all_language_pairs())}"
+                f"Please enter a number between 1 and {len(language_pairs)}",
+                err=True,
             )
+            sys.exit(1)
     else:
         # Check if the language pair exists
         try:
@@ -380,25 +404,172 @@ def config_default_language_pair():
                 language_to_learn, mother_tongue = config_handler.get_language_pair(choice)
         # The user entered an invalid language pair
         except ValueError as error:
-            click.echo(f"{RED}{error}{RESET}")
-            click.echo(f"The format is {BOLD}language_to_learn:mother_tongue{RESET}")
+            click.secho(str(error), fg="red", err=True)
+            click.echo(
+                f"The format is {click.style('language_to_learn:mother_tongue', bold=True)}",
+                err=True,
+            )
             sys.exit(1)
 
         # Set the language pair as the default
         config_handler.set_default_language_pair(language_to_learn, mother_tongue)
         click.echo(
-            f"{BOLD}{language_to_learn}:{mother_tongue}{RESET} {GREEN} has been set as"
-            f" the default language pair{RESET} ✅"
+            f"{click.style(f'{language_to_learn}:{mother_tongue}', bold=True)} "
+            f"{click.style('has been set as the default language pair', fg='green')} ✅"
         )
 
 
-# @config.command("dir")
-# def config_dir():
-#    """
-#    Set the directory where the list and the Anki deck are stored.
-#    """
-#    custom_app_data_dir = click.prompt("Enter the path for the new directory", type=str)
-#    setup_dir(custom_app_data_dir)
+@config.command("remove")
+def config_remove_language_pair():
+    """
+    Remove an existing language pair.
+    """
+    language_pairs = print_all_language_pairs()
+    if not language_pairs:
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(
+            "No language pairs found. Run 'vocabmaster setup' to add one before removing.",
+            err=True,
+        )
+        sys.exit(1)
+
+    choices_input = click.prompt(
+        "Type the language pair(s) or number(s) to remove (comma-separated)",
+        type=str,
+    ).strip()
+
+    raw_choices = [item.strip() for item in choices_input.split(",") if item.strip()]
+    if not raw_choices:
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo("No language pairs selected for removal.", err=True)
+        sys.exit(1)
+
+    selections = []
+    seen_pairs = set()
+
+    for choice in raw_choices:
+        if choice.isdigit():
+            idx = int(choice) - 1
+            if 0 <= idx < len(language_pairs):
+                language_to_learn = language_pairs[idx]["language_to_learn"]
+                mother_tongue = language_pairs[idx]["mother_tongue"]
+            else:
+                click.secho("Invalid choice", fg="red", err=True)
+                click.echo(
+                    f"Please enter a number between 1 and {len(language_pairs)}",
+                    err=True,
+                )
+                sys.exit(1)
+        else:
+            try:
+                language_to_learn, mother_tongue = config_handler.get_language_pair(choice)
+            except ValueError as error:
+                click.secho(str(error), fg="red", err=True)
+                click.echo(
+                    f"The format is {click.style('language_to_learn:mother_tongue', bold=True)}",
+                    err=True,
+                )
+                sys.exit(1)
+
+            language_to_learn = language_to_learn.casefold()
+            mother_tongue = mother_tongue.casefold()
+
+            pair_exists = any(
+                pair["language_to_learn"] == language_to_learn
+                and pair["mother_tongue"] == mother_tongue
+                for pair in language_pairs
+            )
+
+            if not pair_exists:
+                click.secho("Error: ", fg="red", nl=False, err=True)
+                click.echo(
+                    f"The language pair {language_to_learn}:{mother_tongue} was not found.",
+                    err=True,
+                )
+                sys.exit(1)
+
+        pair_key = (language_to_learn, mother_tongue)
+        if pair_key not in seen_pairs:
+            selections.append(pair_key)
+            seen_pairs.add(pair_key)
+
+    display_pairs = [f"{lang}:{mother}" for lang, mother in selections]
+    if len(display_pairs) == 1:
+        confirm_prompt = f"Remove {display_pairs[0]} from your configured language pairs?"
+    else:
+        confirm_prompt = (
+            "Remove the following language pairs from your configuration?\n"
+            + ", ".join(display_pairs)
+        )
+
+    if not click.confirm(confirm_prompt, default=False):
+        click.echo("No changes made.")
+        return
+
+    removed_default = False
+    for language_to_learn, mother_tongue in selections:
+        try:
+            removed_default = (
+                config_handler.remove_language_pair(language_to_learn, mother_tongue)
+                or removed_default
+            )
+        except ValueError as error:
+            click.secho("Error: ", fg="red", nl=False, err=True)
+            click.echo(error, err=True)
+            sys.exit(1)
+
+        click.echo(
+            f"{click.style(f'{language_to_learn}:{mother_tongue}', bold=True)} "
+            f"{click.style('has been removed', fg='green')} ✅"
+        )
+
+    remaining_pairs = config_handler.get_all_language_pairs()
+
+    if removed_default:
+        click.secho("Heads-up: the default language pair was removed.", fg="yellow")
+        if remaining_pairs:
+            click.secho("Run 'vocabmaster config default' to choose a new default.", fg="blue")
+
+    if not remaining_pairs:
+        click.secho("There are no language pairs configured now.", fg="yellow")
+        click.secho("Use 'vocabmaster setup' to add a new language pair.", fg="blue")
+
+
+@config.command("dir")
+@click.argument("directory", required=False)
+def config_dir(directory):
+    """
+    Set the dir where the vocab list and Anki deck are stored.
+    """
+    current_dir = config_handler.get_data_directory()
+    click.secho("Current storage directory:", fg="blue")
+    click.echo(current_dir)
+
+    if directory is None:
+        directory_input = click.prompt(
+            "Enter the directory to store your CSV and Anki files",
+            default=str(current_dir),
+        )
+    else:
+        directory_input = directory
+
+    target_path = Path(directory_input).expanduser()
+    if target_path.exists() and not target_path.is_dir():
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(f"{target_path} exists and is not a directory.", err=True)
+        sys.exit(1)
+
+    try:
+        target_path.mkdir(parents=True, exist_ok=True)
+    except OSError as error:
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(f"Unable to use '{target_path}': {error}", err=True)
+        sys.exit(1)
+
+    config_handler.set_data_directory(target_path)
+    click.secho("Storage updated!", fg="green")
+    click.echo(f"Vocabulary CSV and Anki decks will now be stored in {target_path}")
+    click.echo(f"You can also edit {config_handler.get_config_filepath()} directly.")
 
 
 @config.command("key")
@@ -407,13 +578,14 @@ def config_key():
     Set the OpenAI API key.
     """
     if openai_api_key_exists():
-        click.echo(f"{GREEN}OpenAI API key found!{RESET}")
-        click.echo()
-        click.echo(f"You can use '{BOLD}vocabmaster translate{RESET}' to generate translations.")
+        click.secho("OpenAI API key found!", fg="green")
         click.echo()
         click.echo(
-            "If you only want to generate your Anki deck, you can use"
-            f" '{BOLD}vocabmaster anki{RESET}'."
+            f"You can use '{click.style('vocabmaster translate', bold=True)}' to generate translations."
+        )
+        click.echo()
+        click.echo(
+            f"If you only want to generate your Anki deck, you can use '{click.style('vocabmaster anki', bold=True)}'."
         )
     if not openai_api_key_exists():
         openai_api_key_explain()
@@ -423,7 +595,7 @@ def openai_api_key_explain():
     """
     Explain how to set up the OpenAI API key.
     """
-    click.echo(f"{RED}You need to set up an OpenAI API key.{RESET}")
+    click.secho("You need to set up an OpenAI API key.", fg="red")
     click.echo()
     click.echo(
         "You can generate API keys in the OpenAI web interface. See"
@@ -442,9 +614,10 @@ def show():
     """
     Show all the language pairs that have been set up.
     """
-    print_all_language_pairs()
-    click.echo(f"{BLUE}You can change the default at any time by running:{RESET}")
-    click.echo(f"{BOLD}vocabmaster config default{RESET}")
+    language_pairs = print_all_language_pairs()
+    if language_pairs:
+        click.secho("You can change the default at any time by running:", fg="blue")
+        click.secho("vocabmaster config default", bold=True)
 
 
 @vocabmaster.command()
@@ -459,46 +632,74 @@ def tokens():
     not the total cost of the translation.
     The total cost (prompt + translation) cannot exceed $0.008192 per request, though.
     """
-    language_to_learn = config_handler.get_default_language_pair()["language_to_learn"]
-    mother_tongue = config_handler.get_default_language_pair()["mother_tongue"]
+    default_pair = config_handler.get_default_language_pair()
+    if default_pair is None:
+        click.secho("Error: ", fg="red", nl=False, err=True)
+        click.echo(
+            "No default language pair found. Run 'vocabmaster setup' before estimating costs.",
+            err=True,
+        )
+        sys.exit(1)
+
+    language_to_learn = default_pair["language_to_learn"]
+    mother_tongue = default_pair["mother_tongue"]
     translations_filepath, anki_file = setup_files(setup_dir(), language_to_learn, mother_tongue)
 
     if csv_handler.vocabulary_list_is_empty(translations_filepath):
-        click.echo(f"{RED}The list is empty!{RESET}")
-        click.echo("Please add words to the list before running this command.")
+        click.secho("The list is empty!", fg="red", err=True)
+        click.echo("Please add words to the list before running this command.", err=True)
         sys.exit(0)
 
     try:
         words_to_translate = csv_handler.get_words_to_translate(translations_filepath)
     except Exception as error:
-        click.echo(f"{BLUE}Status:{RESET} {error}")
-        click.echo("Therefore, the cost of the next prompt cannot be estimated.")
+        click.secho("Status: ", fg="blue", nl=False, err=True)
+        click.echo(error, err=True)
+        click.echo("Therefore, the cost of the next prompt cannot be estimated.", err=True)
     else:
         prompt = gpt_integration.format_prompt(language_to_learn, mother_tongue, words_to_translate)
         estimated_cost = gpt_integration.estimate_prompt_cost(prompt)["gpt-3.5-turbo"]
-        click.echo(f"The estimated cost of the next prompt is {BLUE}${estimated_cost}{RESET}.")
+        click.echo(
+            f"The estimated cost of the next prompt is {click.style(f'${estimated_cost}', fg='blue')}."
+        )
 
 
 def print_default_language_pair():
     """
     Print the current default language pair.
     """
-    click.echo(f"{BLUE}The current default language pair is:{RESET}")
-    default_language_to_learn = config_handler.get_default_language_pair()["language_to_learn"]
-    default_mother_tongue = config_handler.get_default_language_pair()["mother_tongue"]
-    click.echo(f"{BOLD}{ORANGE}{default_language_to_learn}:{default_mother_tongue}{RESET}")
+    click.secho("The current default language pair is:", fg="blue")
+    default_pair = config_handler.get_default_language_pair()
+    if default_pair is None:
+        click.secho("No default language pair configured yet.", fg="yellow")
+        click.echo()
+        return None
+
+    click.secho(
+        f"{default_pair['language_to_learn']}:{default_pair['mother_tongue']}",
+        fg="yellow",
+        bold=True,
+    )
     click.echo()
+    return default_pair
 
 
 def print_all_language_pairs():
     """
     Print all the language pairs that have been set up.
     """
-    click.echo(f"{BLUE}The following language pairs have been set up:{RESET}")
+    click.secho("The following language pairs have been set up:", fg="blue")
     language_pairs = config_handler.get_all_language_pairs()
+    if not language_pairs:
+        click.secho("No language pairs found yet.", fg="yellow")
+        click.echo(f"Use {click.style('vocabmaster setup', bold=True)} to add a new language pair.")
+        click.echo()
+        return []
+
     for idx, language_pair in enumerate(language_pairs, start=1):
         click.echo(f"{idx}. {language_pair['language_to_learn']}:{language_pair['mother_tongue']}")
     click.echo()
+    return language_pairs
 
 
 def handle_rate_limit_error():
